@@ -10,6 +10,20 @@ except ImportError:
     DjangoBaseTestCase = TestCase
 
 
+from .live_server_helper import HAS_LIVE_SERVER_SUPPORT
+
+
+def is_transaction_test_case(item):
+
+    if 'transaction_test_case' in item.keywords:
+        return True
+
+    if HAS_LIVE_SERVER_SUPPORT and 'live_server' in item.funcargs:
+        return True
+
+    return False
+
+
 def is_django_unittest(item):
     """
     Returns True if the item is a Django test case, otherwise False.
@@ -23,7 +37,7 @@ def get_django_unittest(item):
     Returns a Django unittest instance that can have _pre_setup() or
     _post_teardown() invoked to setup/teardown the database before a test run.
     """
-    if 'transaction_test_case' in item.keywords:
+    if is_transaction_test_case(item):
         cls = TransactionTestCase
     elif item.config.option.no_db:
         cls = TestCase
@@ -35,17 +49,24 @@ def get_django_unittest(item):
 
 
 def django_setup_item(item):
-    if 'transaction_test_case' in item.keywords:
+    if is_transaction_test_case(item):
         # Nothing needs to be done
         pass
     else:
         # Use the standard TestCase teardown
         get_django_unittest(item)._pre_setup()
 
+    # django_setup_item will not be called if the test is skipped, but teardown
+    # will always be called. Set this flag to tell django_teardown_item if
+    # it should act or not
+    item.keywords['_django_setup'] = True
+
 
 def django_teardown_item(item):
+    if not item.keywords.get('_django_setup'):
+        return
 
-    if 'transaction_test_case' in item.keywords:
+    if is_transaction_test_case(item):
         # Flush the database and close database connections
         # Django does this by default *before* each test instead of after
         for db in connections:
